@@ -277,7 +277,7 @@ pcheck.table <- function(tab=NULL, conn=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=N
         tabx <- NULL
       } else if (tabresp == "R Object") {
         objlst <- c(ls(pos=1, all.names=TRUE),
-		ls(envir=as.environment("package:FIESTA"), pattern="WY"))
+		          ls(envir=as.environment("package:FIESTA"), pattern="WY"))
         objlst <- objlst[sapply(objlst, function(x) is.data.frame(get(x)))]
         tabobj <- select.list(objlst, title=caption, multiple=FALSE)
         if (tabobj == "") stop("")
@@ -286,7 +286,7 @@ pcheck.table <- function(tab=NULL, conn=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=N
           if (!returnsf) tabx <- tabx$data
       } else if (tabresp == "csv") {
         tabfn <- choose.files(default=getwd(), caption=caption,
-			filters=Filters[c("csv", "All"),], multi=FALSE)
+			             filters=Filters[c("csv", "All"),], multi=FALSE)
         if (tabfn == "") stop("")
       } else if (tabresp == "shp") {
         shpfn <- choose.files(default=getwd(), caption="Select point shapefile",
@@ -391,7 +391,7 @@ pcheck.table <- function(tab=NULL, conn=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=N
         return(NULL)
       } else {
         stop(tabnm, " is invalid")       
-	  }
+	    }
     }
   }
 
@@ -595,8 +595,18 @@ pcheck.states <- function (states, statereturn="MEANING", gui=FALSE, RS=NULL,
 
   ## Set column where state name is from
   col <- ifelse(all(states %in% ref_state$VALUE), "VALUE",
-		ifelse(all(states %in% ref_state$ABBR), "ABBR",
-			ifelse(all(states %in% ref_state$MEANING), "MEANING")))
+		        ifelse(all(states %in% ref_state$ABBR), "ABBR",
+			         ifelse(all(states %in% ref_state$MEANING), "MEANING", "NONE")))
+  if (col == 'NONE') {
+    statestest <- ref_state[ref_state$VALUE %in% states | ref_state$ABBR %in% states | 
+                              ref_state$MEANING %in% states, statereturn]
+    if (length(statestest) < length(states)) {
+      stop("invalid states")
+    } else {
+      states <- statestest
+      col <- "MEANING"
+    }
+  }
   if (col == "VALUE") states <- as.numeric(states)
 
   ## Get states to return
@@ -613,7 +623,7 @@ pcheck.states <- function (states, statereturn="MEANING", gui=FALSE, RS=NULL,
 #' @rdname pcheck_desc
 #' @export
 pcheck.object <- function(obj=NULL, objnm=NULL, warn=NULL, caption=NULL,
-	stopifnull=FALSE, gui=FALSE, list.items=NULL){
+	                        stopifnull=FALSE, gui=FALSE, list.items=NULL){
   ## DESCRIPTION: checks object name
 
   ## Adds to file filters to Cran R Filters table.
@@ -642,7 +652,7 @@ pcheck.object <- function(obj=NULL, objnm=NULL, warn=NULL, caption=NULL,
         objx <- NULL
       } else if (objresp == "R Object") {
         objlst <- c(ls(pos=1, all.names=TRUE),
-		ls(envir=as.environment("package:FIESTA"), pattern="WY"))
+		         ls(envir=as.environment("package:FIESTA"), pattern="WY"))
         objlst <- objlst[sapply(objlst, function(x) is.data.frame(get(x)))]
         obj <- select.list(objlst, title=caption, multiple=FALSE)
         if (obj == "") stop("")
@@ -650,13 +660,13 @@ pcheck.object <- function(obj=NULL, objnm=NULL, warn=NULL, caption=NULL,
         #if (!is.list(objx)) stop("must be list object")
       } else if (objresp == "rda") {
         objfn <- choose.files(default=getwd(), caption=caption,
-			filters=Filters[c("rda", "All"),], multi=FALSE)
+			                        filters=Filters[c("rda", "All"),], multi=FALSE)
         if (objfn == "") stop("")
         objx <- get(load(objfn))
         #if (!is.list(objx)) stop("must be list object")
       } else if (objresp == "rds") {
         objfn <- choose.files(default=getwd(), caption=caption,
-			filters=Filters[c("rds", "All"),], multi=FALSE)
+			                        filters=Filters[c("rds", "All"),], multi=FALSE)
         if (objfn == "") stop("")
         objx <- readRDS(file = objfn)
         #if (!is.list(objx)) stop("must be list object")
@@ -701,9 +711,9 @@ pcheck.object <- function(obj=NULL, objnm=NULL, warn=NULL, caption=NULL,
     } else {
       if (any(unlist(lapply(objx[list.items], is.null)))) {
         listnames <- (names(which(unlist(lapply(objx[list.items], is.null)))))
-		if (stopifnull) {
+		    if (stopifnull) {
           stop("tables are null: ", toString(listnames))
-		}
+		    }
       }
     }
   }
@@ -857,7 +867,7 @@ pcheck.output <- function(out_fmt = "csv", outsp_fmt = "shp",
   } else {
     ext <- getext(chkfn)
   }
- 
+
   if (is.null(chkfn) || overwrite_dsn || !overwrite_dsn) {
     out_dsn <- getoutfn(out_dsn, outfn.pre = outfn.pre, 
                         outfolder = outfolder,
@@ -881,6 +891,12 @@ pcheck.output <- function(out_fmt = "csv", outsp_fmt = "shp",
 
   outfolder <- normalizePath(dirname(out_dsn))
   out_dsn <- basename(out_dsn)
+  
+  ## Check out_dsn
+  if (!is.null(out_dsn) && out_fmt == "csv") {
+    message("out_fmt in savedata_opts = 'csv' and out_dsn is not null...")
+    out_fmt <- 'sqlite'
+  }
 
   ## check append_layer
   if (append_layer) {
