@@ -24,21 +24,38 @@ polyfix.sf <- function(x, nolonglat=TRUE) {
   xvalid <- tryCatch(sf::st_is_valid(x),
                      error=function(e) {
                        return(NULL) })
+
   if (is.null(xvalid) || any(is.na(xvalid)) || any(!xvalid)) {
-    sf_use_s2(FALSE)
+    
+    ## Use sf function to make valid
+    x <- sf::st_make_valid(x)
+  
+    ## If valid, return
+    if (all(sf::st_is_valid(x))) {
+      ## Check longlat
+      if (nolonglat) {
+        x <- checksf.longlat(x)
+      } 
+      x <- sf::st_cast(x, "MULTIPOLYGON")
+      return(x)
+    }
+    
+    
+    sf::sf_use_s2(FALSE)
     
     ## Check for bad geometries
     badgeomtypes <- c("LINESTRING", "MULTIPOINT", "MULTILINESTRING",
                       "CIRCULARSTRING", "COMPOUNDCURVE", "CURVEPOLYGON",
                       "MULTICURVE", "MULTISURFACE", "CURVE", "SURFACE")
-    if (any(unique(sf::st_geometry_type(x)) %in% badgeomtypes)) {
-      x <- sf::st_cast(x, "MULTIPOLYGON")
-    }
+
+    # if (any(unique(sf::st_geometry_type(x)) %in% badgeomtypes)) {
+    #   x <- sf::st_cast(x, "MULTIPOLYGON")
+    # }
     
     xvalid <- tryCatch(sf::st_is_valid(x),
                        error=function(e) {
                          return(NULL) })
-    
+
     if (is.null(xvalid) || any(is.na(xvalid)) || any(!xvalid)) {
       x <- sf::st_make_valid(x, 
                            geos_method = 'valid_structure', 
@@ -76,6 +93,7 @@ polyfix.sf <- function(x, nolonglat=TRUE) {
         }  
       }  
     }
+    x <- sf::st_cast(x, "MULTIPOLYGON")
   }
   ## Remove empty geometries
 #  if (sum(sf::st_is_empty(x)) > 0) {
@@ -285,15 +303,12 @@ check.extents <- function(bbox1, bbox2, showext=FALSE, layer1nm=NULL,
 
   bbox1sf$fld <- 1
   bbox2sf$fld <- 1
+  
 
-  ## bbox2 within bbox1
-  intpct1 <- suppressWarnings(tabulateIntersections(layer1=bbox2sf,
-			layer1fld="fld", layer2=bbox1sf))$int.pct
-
-  ## bbox1 within bbox2
-#  intpct2 <- suppressWarnings(tabulateIntersections(layer1=bbox1sf,
-#			layer1fld="fld", layer2=bbox2sf))$int.pct
-
+  ## percent of bbox2 within bbox1
+  intpct1 <- tabulateIntersections(layer1 = bbox1sf,
+                                   layer1fld = "fld", 
+                                   layer2 = bbox2sf)$int.pct
 
   if (showext) {
     bbox12sfc <- append(bbox1sfc, bbox2sfc)
