@@ -31,7 +31,7 @@ write2sqlite <- function(layer,
   ##  Writes data frame to SQLite database.
   ####################################################################################
   appendtext <- ifelse(append_layer, "appending", "writing")
- 
+
   if (is.null(dbconn) || !DBI::dbIsValid(dbconn)) {
     ## Check SQLite connection
     ###########################################################
@@ -53,7 +53,6 @@ write2sqlite <- function(layer,
   if (lowernames) {
     names(layer) <- tolower(names(layer))
   }
-  
 
   ## Change columns of type POSIX* to character before writing to database
   if (any(grepl("POSIX", lapply(layer, class)))) {
@@ -65,7 +64,11 @@ write2sqlite <- function(layer,
 
   ## Write table to database
   DBI::dbWriteTable(dbconn, out_name, layer, append=append_layer, overwrite=overwrite)
-  message(paste(appendtext, out_name, "to", SQLitefn))
+  if (!is.null(outfolder)) {
+    message(paste(appendtext, out_name, "to", normalizePath(file.path(outfolder, SQLitefn), winslash = "/")))
+  } else {
+    message(paste(appendtext, out_name, "to", SQLitefn))
+  }
 
   if (!is.null(index.unique)) {
     if (!is.list(index.unique)) {
